@@ -895,6 +895,8 @@ class ChangeCellValue(_StepsChangingCommand):
         self._undo_command = ChangeCellValue(self._row, self._col, step.get_value(self._col))
         step.change(self._col, self._value)
         self._step(context).remove_empty_columns_from_end()
+        assert self._step(context).get_value(self._col).strip() == self._value.strip(), \
+            'Should have correct value after change'
         return True
 
     def _get_undo_command(self):
@@ -953,6 +955,7 @@ class InsertCell(_StepsChangingCommand):
 
     def change_steps(self, context):
         self._step(context).shift_right(self._col)
+        assert self._step(context).get_value(self._col) == '', 'Should have an empty value after insert'
         return True
 
     def _get_undo_command(self):
@@ -1017,6 +1020,7 @@ class AddRow(_RowChangingCommand):
     def _change_value(self, context):
         row = self._row if self._row != -1 else len(context.steps)
         context.add_step(row)
+        assert not(any(i for i in self._step(context).as_list() if i)), 'Should have an empty row after add'
 
     def _get_undo_command(self):
         return DeleteRow(self._row)
